@@ -18,8 +18,12 @@
 #include <wchar.h>
 
 /* curses */
+#ifndef SFEED_MINICURSES
 #include <curses.h>
 #include <term.h>
+#else
+#include "minicurses.h"
+#endif
 
 #define LEN(a) sizeof((a))/sizeof((a)[0])
 
@@ -27,18 +31,11 @@
 #define SCROLLBAR_SYMBOL_BAR   "\xe2\x94\x82" /* symbol: "light vertical" */
 #define SCROLLBAR_SYMBOL_TICK  " "
 
-/* See the README for some color theme examples. */
-#define THEME_ITEM_NORMAL()           do {                            } while(0)
-#define THEME_ITEM_FOCUS()            do {                            } while(0)
-#define THEME_ITEM_BOLD()             do { attrmode(ATTR_BOLD_ON);    } while(0)
-#define THEME_ITEM_SELECTED()         do { if (p->focused) attrmode(ATTR_REVERSE_ON); } while(0)
-#define THEME_SCROLLBAR_FOCUS()       do {                            } while(0)
-#define THEME_SCROLLBAR_NORMAL()      do { attrmode(ATTR_FAINT_ON);   } while(0)
-#define THEME_SCROLLBAR_TICK_FOCUS()  do { attrmode(ATTR_REVERSE_ON); } while(0)
-#define THEME_SCROLLBAR_TICK_NORMAL() do { attrmode(ATTR_REVERSE_ON); } while(0)
-#define THEME_STATUSBAR()             do { attrmode(ATTR_REVERSE_ON); } while(0)
-#define THEME_INPUT_LABEL()           do { attrmode(ATTR_REVERSE_ON); } while(0)
-#define THEME_INPUT_NORMAL()          do {                            } while(0)
+/* color-theme */
+#ifndef SFEED_THEME
+#define SFEED_THEME "themes/mono.h"
+#endif
+#include SFEED_THEME
 
 static char *plumbercmd = "xdg-open"; /* env variable: $SFEED_PLUMBER */
 static char *pipercmd = "sfeed_content"; /* env variable: $SFEED_PIPER */
@@ -985,15 +982,12 @@ lineeditor(void)
 			if (!nchars)
 				continue;
 			input[--nchars] = '\0';
-			ch = '\b'; /* back */
-			write(1, &ch, 1);
-			ch = ' '; /* blank */
-			write(1, &ch, 1);
-			ch = '\b'; /* back */
-			write(1, &ch, 1);
+			write(1, "\b \b", 3); /* back, blank, back */
 			continue;
 		} else if (ch >= ' ') {
-			write(1, &ch, 1);
+			input[nchars] = ch;
+			write(1, &input[nchars], 1);
+			nchars++;
 		} else if (ch < 0) {
 			switch (sigstate) {
 			case 0:
@@ -1007,7 +1001,6 @@ lineeditor(void)
 			free(input);
 			return NULL;
 		}
-		input[nchars++] = ch;
 	}
 	return input;
 }
